@@ -2,8 +2,10 @@
  *            pilot-qof.c
  *
  *   Sat Feb  5 10:40:03 GMT 2005
- *  Copyright  2005, 2006  Neil Williams
- *  linux@codehelp.co.uk
+ *  Copyright  2005, 2006  Neil Williams <linux@codehelp.co.uk>
+ *
+ *  plu_connect and pq_findcategory based on pilot-link/src/userland.c
+ *  Copyright  2004 Adriaan de Groot <groot@kde.org>
  ****************************************************************************/
 /*
  *  This program is free software; you can redistribute it and/or modify
@@ -28,6 +30,7 @@
 /** @file pilot-qof.c
   @brief Executable interface to the QOF external framework
   @author Copyright (c) 2005, 2006 Neil Williams <linux@codehelp.co.uk>
+  @author Copyright (c) 2004 Adriaan de Groot <groot@kde.org>
 */
 
 #define _GNU_SOURCE
@@ -123,7 +126,7 @@ typedef enum {
 
 static const gchar *env_pilotport = "PILOTPORT";
 
-/* copied from private pilot-link 0.12 source */
+/* copied from pilot-link 0.12 source */
 static gint 
 plu_connect(gchar* plu_port, gint plu_quiet)
 {
@@ -854,6 +857,13 @@ main (int argc, const char *argv[])
 	plu_quiet = 0;
 	plu_port = NULL;
 
+#ifdef ENABLE_NLS
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+#endif
+
 	help_header_text = _("\n"
 		"   Query Palm databases as objects and save to XML.\n"
 
@@ -869,12 +879,6 @@ main (int argc, const char *argv[])
 		"   Options are -c -t -w, -d or -e.\n"
 		"   option -u requires -a\n\n");
 
-#ifdef ENABLE_NLS
-	setlocale (LC_ALL, "");
-	bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-#endif
 	pc = poptGetContext (PACKAGE, argc, argv, options, 0);
 
 	poptSetOtherOptionHelp (pc, help_header_text);
@@ -913,7 +917,7 @@ main (int argc, const char *argv[])
 				qof_mod_sql (sql_query, &pilot_qof_context->qof);
 				if (!filename)
 				{
-					filename = g_strdup ("/tmp/.pq");
+					filename = g_strdup (QOF_STDOUT);
 				}
 				palm_command = qof_op_empty;
 				break;
@@ -921,8 +925,6 @@ main (int argc, const char *argv[])
 		case qof_op_sql_file:
 			{
 				qof_mod_sql_file (sql_file, &pilot_qof_context->qof);
-				if (!filename)
-					filename = g_strdup ("/tmp/.pq");
 				palm_command = qof_op_empty;
 				break;
 			}
@@ -1080,9 +1082,22 @@ main (int argc, const char *argv[])
 	switch (palm_command)
 	{
 	case qof_op_empty:
+	{
+		pilot_qof_context->qof.filename = g_strdup (filename);
+		if ((pilot_qof_context->invoice_city)
+			|| (pilot_qof_context->invoice_vendor))
+		{
+			check_invoice_handler (pilot_qof_context);
+			if (pilot_qof_context->qof.error)
+				return EXIT_FAILURE;
+			pq_invoice_xmlfile (pilot_qof_context);
+		}
+		else
+			qof_cmd_xmlfile (&pilot_qof_context->qof);
+		break;
+	}
 	case qof_op_offline:
 		{
-			DEBUG (" file mode:%s", filename);
 			pilot_qof_context->qof.filename = g_strdup (filename);
 			if ((pilot_qof_context->invoice_city)
 				|| (pilot_qof_context->invoice_vendor))
