@@ -616,15 +616,15 @@ exp_getCurrency (QofExpense * e)
 	return qe->currency;
 }
 
-static gnc_numeric
+static QofNumeric
 exp_getAmount (QofExpense * e)
 {
 	Expense_t *qe;
-	gnc_numeric amount;
-	double pi_amount;
+	QofNumeric amount;
+	gdouble pi_amount;
 	gchar *numeric_char;
 
-	amount = gnc_numeric_zero ();
+	amount = qof_numeric_zero ();
 	g_return_val_if_fail (e != NULL, amount);
 	qe = &e->wrap;
 	if (qe->amount == 0)
@@ -632,16 +632,16 @@ exp_getAmount (QofExpense * e)
 	/* floating point as a string converts to gnc_numeric */
 	pi_amount = strtod (qe->amount, NULL);
 	if (e->currency)
-		amount = double_to_gnc_numeric (pi_amount, e->currency->fraction,
-			GNC_HOW_DENOM_EXACT | GNC_HOW_RND_ROUND);
+		amount = qof_numeric_from_double (pi_amount, e->currency->fraction,
+			QOF_HOW_DENOM_EXACT | QOF_HOW_RND_ROUND);
 	else						/* default: use the most common fraction in the Palm currency list. */
-		amount = double_to_gnc_numeric (pi_amount, 100,
-			GNC_HOW_DENOM_EXACT | GNC_HOW_RND_ROUND);
-	numeric_char = gnc_numeric_to_string (amount);
+		amount = qof_numeric_from_double (pi_amount, 100,
+			QOF_HOW_DENOM_EXACT | QOF_HOW_RND_ROUND);
+	numeric_char = qof_numeric_to_string (amount);
 	g_free (numeric_char);
-	if (gnc_numeric_check (amount) == GNC_ERROR_OK)
+	if (qof_numeric_check (amount) == QOF_ERROR_OK)
 		return amount;
-	return gnc_numeric_zero ();
+	return qof_numeric_zero ();
 }
 
 static const gchar *
@@ -814,13 +814,13 @@ exp_setCurrency (QofExpense * e, gint code)
 }
 
 static void
-exp_setAmount (QofExpense * e, gnc_numeric h)
+exp_setAmount (QofExpense * e, QofNumeric h)
 {
 	Expense_t *qe;
 
 	g_return_if_fail (e != NULL);
 	qe = &e->wrap;
-	e->temp_amount = gnc_numeric_to_double (h);
+	e->temp_amount = qof_numeric_to_double (h);
 	e->reset_amount = TRUE;
 	/* if an amount can ever be set without a currency_code,
 	   this needs to be reviewed. */
